@@ -22,11 +22,11 @@ github_install_package <- function(user, package, lib){
   untar(mytmp);
   
   #detect R path. Must be a better way.
-  R <- parallel::defaultClusterOptions$rprog; 
+  R <- from("parallel", "defaultClusterOptions")$rprog; 
   
   #call out to system
   system_capture(
     R,
     paste("CMD", "INSTALL", paste(package, "master", sep="-"), paste("--library", deparse(lib), sep="="))
   );
-}
\ No newline at end of file
+}
